/*
 * @Author: mypx
 * @Date: 2025-10-15 13:03:28
 * @LastEditTime: 2025-10-15 14:58:18
 * @LastEditors: mypx mypx_coder@163.com
 * @Description: 
 */
#ifndef __BSP_TEC_H__
#define __BSP_TEC_H__

void bsp_tec_init(void);

// 这俩接口内部必须做好互斥，不能同时打开
void bsp_tec_cooling_open(void);
void bsp_tec_heating_open(void);

void bsp_tec_close(void);
// pwm: 0.0 ~ 1.0
void bsp_tec_cooling_adjust(float pwm);
// pwm: 0.0 ~ 1.0
void bsp_tec_heating_adjust(float pwm);



void bsp_fan_start(void);
void bsp_fan_stop(void);
#endif // __BSP_TEC_H__
